@@ -13,7 +13,6 @@ from django.core.urlresolvers import reverse
 from django.core.cache import cache
 from django.conf import settings
 
-from tendenci.libs.boto_s3.utils import StaticStorage
 from tendenci.core.base.template_tags import parse_tag_kwargs
 from tendenci.core.base.utils import url_exists
 from tendenci.apps.profiles.models import Profile
@@ -470,7 +469,7 @@ class PhotoImageURL(Node):
 
         # return empty unicode string
         if not photo.pk:
-            return StaticStorage().url(getattr(settings, 'DEFAULT_IMAGE_URL'))
+            return "%s%s" % (getattr(settings, 'STATIC_URL'), getattr(settings, 'DEFAULT_IMAGE_URL'))
 
         cache_key = generate_image_cache_key(file=str(photo.pk), size=self.size, pre_key="photo", crop=self.crop, unique_key=str(photo.pk), quality=self.quality, constrain=self.constrain)
         cached_image_url = cache.get(cache_key)
@@ -558,7 +557,7 @@ class ImageURL(Node):
             return url
 
         # return the default image url
-        return StaticStorage().url(getattr(settings, 'DEFAULT_IMAGE_URL'))
+        return "%s%s" % (getattr(settings, 'STATIC_URL'), getattr(settings, 'DEFAULT_IMAGE_URL'))
 
 
 @register.tag
